@@ -1,3 +1,4 @@
+#![allow(dead_code)]
 //! # LT FM-Index
 //!
 //! `lt-fm-index` is library for locate and count nucleotide sequence (ATGC) string.  
@@ -16,7 +17,7 @@
 //! - There are two main functions.
 //!     - count: Count the number of patterns in the text
 //!     - locate: Locate pattern index in text (KLT can be specified to enable or disable)
-//! ## Future work
+//! ## Future works
 //! - IO
 //! - Input text can be `slice`
 //! ## Example
@@ -51,6 +52,7 @@
 //! - Yuta Mori. [`libdivsufsort`](https://github.com/y-256/libdivsufsort)
 
 mod bwt;
+// TODO: IO module
 
 use bwt::Bwt;
 use libdivsufsort_rs::{divsufsort64, bw_transform64};
@@ -119,11 +121,13 @@ pub struct FmIndex {
 }
 
 impl FmIndex {
+    /// Create new fm-index with configuration
     #[inline]
     pub fn new(config: &Config, text: Vec<u8>) -> Self {
         let text_len = text.len() as u64;
         // suffix_array
         let suffix_array = divsufsort64(&text).unwrap();
+        // TODO: To save mem space, not use cloned text
         // bwt & primary index
         let (bwt_string, pidx) = {
             let mut bwt = text.clone();
@@ -206,11 +210,13 @@ impl FmIndex {
             bwt: bwt,
         }
     }
+    /// Count the number of pattern in the text
     #[inline]
     pub fn count(&self, pattern: &[u8]) -> u64 {
         let pos_range = self.lf_map(pattern);
         pos_range.1 - pos_range.0
     }
+    /// Locate index of the pattern in the text (not use k-mer lookup table)
     #[inline]
     pub fn locate(&self, pattern: &[u8]) -> Vec<u64> {
         let pos_range = self.lf_map(pattern);
@@ -245,6 +251,7 @@ impl FmIndex {
         let idx = nc_to_idx(&c);
         (self.count_array[idx], self.count_array[idx+1])
     }
+    /// Locate index of the pattern in the text with k-mer lookup table
     #[inline]
     pub fn locate_with_klt(&self, pattern: &[u8]) -> Vec<u64> {
         let (kmer_size, klt) = self.kmer_lookup_table.as_ref().unwrap();
@@ -378,7 +385,6 @@ fn compress_suffix_array(suffix_array: Vec<i64>, sampling_ratio: u64) -> SuffixA
 #[cfg(test)]
 mod tests {
     use super::*;
-    use libdivsufsort_rs::*;
 
     // For cross check
     use fm_index::converter::RangeConverter;
@@ -460,4 +466,14 @@ mod tests {
         let locations = fm_index.locate_with_klt(&pattern);
         assert_eq!(locations, vec![5,18]);
     }
+    
+    #[test]
+    fn mem_size_check() {
+        println!("size of FmIndex: {}", std::mem::size_of::<FmIndex>());
+        println!("size of CountArray: {}", std::mem::size_of::<CountArray>());
+        println!("size of SuffixArray: {}", std::mem::size_of::<SuffixArray>());
+        println!("size of KmerLookupTable: {}", std::mem::size_of::<KmerLookupTable>());
+        println!("size of klt option: {}", std::mem::size_of::<Option<KmerLookupTable>>());
+        println!("size of Bwt: {}", std::mem::size_of::<Bwt>());
+    }
 }
